#!/usr/bin/env python3
"""
SSL Certificate Checker
Parameters:
    - IP: Target IP address
    - port: Target port number (default: 443)
"""
import ssl
import socket
import datetime
import argparse

def check_ssl_cert(ip, port=443):
    try:
        context = ssl.create_default_context()
        with socket.create_connection((ip, port)) as sock:
            with context.wrap_socket(sock, server_hostname=ip) as ssock:
                cert = ssock.getpeercert()
                
                # Parse certificate details
                subject = dict(x[0] for x in cert['subject'])
                issuer = dict(x[0] for x in cert['issuer'])
                not_after = datetime.datetime.strptime(cert['notAfter'], '%b %d %H:%M:%S %Y %Z')
                
                print(f"Subject: {subject.get('commonName', 'N/A')}")
                print(f"Issuer: {issuer.get('commonName', 'N/A')}")
                print(f"Valid until: {not_after}")
                print(f"SSL Version: {ssock.version()}")
    except Exception as e:
        print(f"Error checking SSL certificate: {str(e)}")

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="SSL Certificate Checker")
    parser.add_argument("ip", help="Target IP address or hostname")
    parser.add_argument("--port", type=int, default=443, help="Target port (default: 443)")
    args = parser.parse_args()
    
    check_ssl_cert(args.ip, args.port)
